@@ -1,6 +1,6 @@
 # Copyright (C) 2008-2009 - INRIA - Michael Baudin
 # Copyright (C) 2009-2010 - DIGITEO - Michael Baudin
-# Copyright (C) 2010 - Sebastien Bihorel
+# Copyright (C) 2010-2014 - Sebastien Bihorel
 #
 # This file must be used under the terms of the CeCILL.
 # This source file is licensed as described in the file COPYING, which
@@ -12,14 +12,13 @@
 # originally written by Michael Baudin for Scilab.
 
 optimsimplex.getve <- function(this=NULL,ive=NULL){
-
-  vertex <- list(x=NULL,n=NULL,fv=NULL)
-  attr(vertex,'type') <- 'T_VERTEX'
+  
+  vertex <- vertex()
   vertex$n <- this$n
   vertex$x <- this$x[ive,,drop=FALSE]
-  vertex$fv <- this$fv[ive]
-
+  vertex$fv <- this$fv[ive,1]
+  
   return(vertex)
-
+  
 }
 
