@@ -1,6 +1,6 @@
 # Copyright (C) 2008-2009 - INRIA - Michael Baudin
 # Copyright (C) 2009-2010 - DIGITEO - Michael Baudin
-# Copyright (C) 2010 - Sebastien Bihorel
+# Copyright (C) 2010-2014 - Sebastien Bihorel
 #
 # This file must be used under the terms of the CeCILL.
 # This source file is licensed as described in the file COPYING, which
@@ -11,36 +11,37 @@
 # This source code is a R port of the optimsimplex component
 # originally written by Michael Baudin for Scilab.
 
-optimsimplex.tostring <- function(this=NULL){
-
+optimsimplex.tostring <- function(x=NULL){
+  
   str <- c()
-  if (this$n==0){
+  if (x$n==0){
     str <- sprintf('Empty simplex (zero dimension)\n')
     return(str)
   }
-  if (this$nbve==0){
+  if (x$nbve==0){
     str <- sprintf('Empty simplex (zero vertices)\n')
     return(str)
   }
-  if (length(this$x)==0){
+  if (length(x$x)==0){
     str <- sprintf('Empty simplex (zero coordinates)\n')
     return(str)
   }
-  if (length(this$fv)==0){
+  if (length(x$fv)==0){
     str <- sprintf('Empty simplex (zero function values)\n')
     return(str)
   }
   
-  for (k in 1:this$nbve){
+  for (k in 1:x$nbve){
     # Compute a string for x
-    ss <- sprintf('%e',this$x[k,1])
-    for (i in 2:this$n){
-      ss <- paste(ss,sprintf('%e',this$x[k,i]))
+    ss <- sprintf('%e',x$x[k,1])
+    if (x$n>1){
+      for (i in 2:x$n){
+        ss <- paste(ss,sprintf('%e',x$x[k,i]))
+      }
     }
-    str[k] <- sprintf('Vertex #%d/%d : fv=%e, x=%s\n',k,this$nbve,this$fv[k],ss)
+    str[k] <- sprintf('Vertex #%d/%d : fv=%e, x=%s\n',k,x$nbve,x$fv[k],ss)
   }
-
+  
   return(str)
-
-}
-
+  
+}
\ No newline at end of file
